ProSHADE: src/proshade/ProSHADE.hpp File Reference

| ProSHADE 0.7.5.4 (MAR 2021) Protein Shape Detection

Classes | Functions
ProSHADE.hpp File Reference

This is the main header file providing the main access class and its functions. More...

`#include "ProSHADE_tasks.hpp"`

Go to the source code of this file.

## Classes
class | ProSHADE_run
| This class provides the access point to the library. More...

## Functions
void | getReBoxedMap (ProSHADE_run *run, proshade_unsign strNo, double *reboxMap, int len)
| This function returns the re-boxed structure map 1D array for the processed structure. More...

## Detailed Description

This is the main header file providing the main access class and its functions.

This file contains the header declarations for the main access class (ProSHADE_run), which the user can use to start a run of the ProSHADE tool. This is generally done by firstly creating and setting a ProSHADE_settings class instance, which is then supplied to the constructor of the ProSHADE_run class defined here. Once the class constructor is run, ProSHADE run with the supplied settings will also be complete and the resulting instance of ProSHADE_run class will contain the results. To access these results, the ProSHADE_run class provides accessor functions.

Copyright by Michal Tykac and individual contributors. All rights reserved.

Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met: 1) Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer. 2) Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution. 3) Neither the name of Michal Tykac nor the names of this code's contributors may be used to endorse or promote products derived from this software without specific prior written permission.

This software is provided by the copyright holder and contributors "as is" and any express or implied warranties, including, but not limitted to, the implied warranties of merchantibility and fitness for a particular purpose are disclaimed. In no event shall the copyright owner or the contributors be liable for any direct, indirect, incidental, special, exemplary, or consequential damages (including, but not limitted to, procurement of substitute goods or services, loss of use, data or profits, or business interuption) however caused and on any theory of liability, whether in contract, strict liability or tort (including negligence or otherwise) arising in any way out of the use of this software, even if advised of the possibility of such damage.

Author
  Michal Tykac
  Garib N. Murshudov

Version
  0.7.5.4

Date
  MAR 2021

Definition in file ProSHADE.hpp.

## Function Documentation

## ◆ getReBoxedMap()

void getReBoxedMap | ( | ProSHADE_run * | run,
|  | proshade_unsign | strNo,
|  | double * | reboxMap,
|  | int | len
| ) |  |

This function returns the re-boxed structure map 1D array for the processed structure.

Parameters

  [in] | run | The ProSHADE_run object from which the values will be drawn.
  [in] | strNo | Index of the structure for which the bounds are to be returned.
  [in] | reboxMap | Array to which the values are to be loaded into.
  [in] | len | The length of the array.

Definition at line 2511 of file ProSHADE.cpp.

2512 {
2513 //================================================ Sanity checks
2514 if ( run->getNoStructures() <= strNo )
2515 {
2516 ProSHADE_internal_messages::printWarningMessage ( run->getVerbose(), "!!! ProSHADE WARNING !!! Requested bounds for structure index which does not exist. Returning empty vector.", "WB00041" );
2517 return ;
2518 }
2519
2520 //================================================ Save the data into the output array
2521 for ( proshade_unsign iter = 0; iter < static_cast<proshade_unsign> ( len ); iter++)
2522 {
2523 reboxMap[iter] = static_cast<double> ( run->getMapValue ( strNo, iter ) );
2524 }
2525
2526 //================================================ Done
2527 return ;
2528
2529 }
ProSHADE_run::getVerbose
proshade_signed getVerbose(void)
This function returns the verbose value.
Definition: ProSHADE.cpp:2350
ProSHADE_internal_messages::printWarningMessage
void printWarningMessage(proshade_signed verbose, std::string message, std::string warnCode)
General stderr message printing (used for warnings).
Definition: ProSHADE_messages.cpp:101
ProSHADE_run::getMapValue
proshade_double getMapValue(proshade_unsign strNo, proshade_unsign mapIndex)
This function returns a single, specific structure map value.
Definition: ProSHADE.cpp:2497
ProSHADE_run::getNoStructures
proshade_unsign getNoStructures(void)
This function returns the number of structures used.
Definition: ProSHADE.cpp:2340